"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseTokenId = exports.TokenIdFlag = exports.FloatFlag = exports.BNflag = void 0;
const tslib_1 = require("tslib");
const near_api_js_1 = require("near-api-js");
const core_1 = require("@oclif/core");
const os_1 = require("os");
const bn_js_1 = tslib_1.__importDefault(require("bn.js"));
const tonic_1 = require("@tonic-foundation/tonic");
const config_1 = require("@tonic-foundation/config");
const utils_1 = require("./utils");
const getKeystore = async () => {
    const HOME_DIR = (0, os_1.homedir)();
    const CREDENTIALS_DIR = '.near-credentials';
    const credentialsPath = require('path').join(HOME_DIR, CREDENTIALS_DIR);
    return new near_api_js_1.keyStores.UnencryptedFileSystemKeyStore(credentialsPath);
};
class BaseCommand extends core_1.Command {
    async init() {
        const { flags } = await this.parse(this.constructor);
        this.globalFlags = flags;
        const connectConfig = (0, config_1.getNearConfig)(flags.networkId);
        this.connectConfig = connectConfig;
        const keyStore = await getKeystore();
        const near = new near_api_js_1.Near({ ...connectConfig, keyStore });
        const account = await near.account(flags.accountId);
        this.account = account;
        this.tonic = new tonic_1.Tonic(account, flags.contractId);
    }
    logTransaction(outcome) {
        const txId = outcome.transaction_outcome.id;
        this.log(`Transaction ID: ${txId}`);
        const explorerLink = `${(0, utils_1.getExplorerUrl)(this.connectConfig.networkId)}/${txId}`;
        this.log(`View in the explorer: ${explorerLink}`);
    }
}
exports.default = BaseCommand;
BaseCommand.flags = {
    networkId: core_1.Flags.string({
        default: 'testnet',
        env: 'NEAR_ENV',
        options: ['mainnet', 'testnet', 'localnet']
    }),
    accountId: core_1.Flags.string({
        env: 'NEAR_ACCOUNT_ID',
        required: true,
    }),
    contractId: core_1.Flags.string({
        env: 'TONIC_CONTRACT_ID',
        required: true,
    }),
};
exports.BNflag = core_1.Flags.build({
    parse: async (s) => new bn_js_1.default(s),
});
exports.FloatFlag = core_1.Flags.build({
    parse: async (s) => {
        const v = parseFloat(s);
        if (isNaN(v)) {
            throw new Error(`${s} is not a number`);
        }
        return v;
    },
});
exports.TokenIdFlag = core_1.Flags.build({
    parse: parseTokenId,
});
async function parseTokenId(s) {
    if (s.toUpperCase() === 'NEAR') {
        return 'NEAR';
    }
    return s;
}
exports.parseTokenId = parseTokenId;
