"use strict";
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const token_1 = require("@tonic-foundation/token");
const utils_1 = require("@tonic-foundation/utils");
const base_1 = tslib_1.__importStar(require("../base"));
class Withdraw extends base_1.default {
    async run() {
        const { args } = await this.parse(Withdraw);
        const { tokenId: rawTokenId, amount: rawAmount } = args;
        let tokenId;
        if (rawTokenId === 'NEAR') {
            tokenId = rawTokenId;
        }
        else if (rawTokenId.startsWith('ft:')) {
            tokenId = rawTokenId;
        }
        else {
            tokenId = `ft:${rawTokenId}`;
        }
        let amount;
        if (tokenId === 'NEAR') {
            amount = (0, utils_1.decimalToBn)(rawAmount, token_1.NEAR_DECIMALS);
        }
        else {
            let tokenMetadata = await (0, token_1.ftMetadata)(this.account, tokenId);
            amount = (0, utils_1.decimalToBn)(rawAmount, tokenMetadata.decimals);
        }
        const { executionOutcome, response } = await this.tonic.withdraw(tokenId, amount);
        this.log(`Withdrew ${args.amount} ${args.tokenId}`, response);
        this.logTransaction(executionOutcome);
    }
}
exports.default = Withdraw;
_a = Withdraw;
Withdraw.description = 'Withdraw exchange balances.';
Withdraw.examples = [`$ tonic withdraw NEAR 0.1`];
Withdraw.flags = {
    ...base_1.default.flags,
};
Withdraw.args = [
    {
        name: 'tokenId',
        description: 'Contract ID of the token to withdraw. Pass `NEAR` for native NEAR.',
        required: true,
        parse: base_1.parseTokenId,
    },
    {
        name: 'amount',
        description: 'Amount to withdraw',
        required: true,
        parse: async (s) => parseFloat(s),
    },
];
